@@ -377,11 +377,11 @@ class GitDiffReporterTest(unittest.TestCase):
             # Expect that both methods that access git diff raise an error
             with self.assertRaises(GitDiffError):
                 print("src_paths_changed() "
-                      "should fail for {0}".format(diff_str))
+                      "should fail for {}".format(diff_str))
                 self.diff.src_paths_changed()
 
             with self.assertRaises(GitDiffError):
-                print("lines_changed() should fail for {0}".format(diff_str))
+                print("lines_changed() should fail for {}".format(diff_str))
                 self.diff.lines_changed('subdir/file1.py')
 
     def test_plus_sign_in_hunk_bug(self):
@@ -479,9 +479,9 @@ class GitDiffReporterTest(unittest.TestCase):
 
     def test_fnmatch(self):
         """Verify that our fnmatch wrapper works as expected."""
-        self.assertEqual(self.diff._fnmatch('foo.py', []), True)
-        self.assertEqual(self.diff._fnmatch('foo.py', ['*.pyc']), False)
-        self.assertEqual(self.diff._fnmatch('foo.pyc', ['*.pyc']), True)
+        self.assertTrue(self.diff._fnmatch('foo.py', []))
+        self.assertFalse(self.diff._fnmatch('foo.py', ['*.pyc']))
+        self.assertTrue(self.diff._fnmatch('foo.pyc', ['*.pyc']))
         self.assertEqual(
             self.diff._fnmatch('foo.pyc', ['*.swp', '*.pyc', '*.py']), True)
 
